@@ -95,8 +95,6 @@ typedef struct cffi_genericu8
     uint8_t* x;
     } cffi_genericu8;
 
-typedef cffi_ffierror (*cffi_fptr_fn_Vec3f32_pconst_Empty_rval_FFIError)(cffi_vec3f32 x0, cffi_empty* x1);
-
 typedef cffi_tupled (*cffi_fptr_fn_Tupled_rval_Tupled)(cffi_tupled x0);
 
 typedef bool (*cffi_fptr_fn_pmut_i64_rval_bool)(int64_t* x0);
@@ -119,12 +117,11 @@ typedef struct cffi_ffioptioninner
     uint8_t is_some;
     } cffi_ffioptioninner;
 
-typedef struct cffi_pointers
+typedef struct cffi_myapiv1
     {
-    cffi_fptr_fn_pmut_i64_rval_bool f1;
-    cffi_fptr_fn_Tupled_rval_Tupled f2;
-    cffi_fptr_fn_Vec3f32_pconst_Empty_rval_FFIError f3;
-    } cffi_pointers;
+    cffi_fptr_fn_pmut_i64_rval_bool ref_mut_option;
+    cffi_fptr_fn_Tupled_rval_Tupled tupled;
+    } cffi_myapiv1;
 
 typedef uint8_t (*cffi_fptr_fn_FFISliceu8_rval_u8)(cffi_ffisliceu8 x0);
 
@@ -146,6 +143,8 @@ int8_t primitive_i8(int8_t x);
 int16_t primitive_i16(int16_t x);
 int32_t primitive_i32(int32_t x);
 int64_t primitive_i64(int64_t x);
+int64_t many_args_5(int64_t x0, int64_t x1, int64_t x2, int64_t x3, int64_t x4);
+int64_t many_args_10(int64_t x0, int64_t x1, int64_t x2, int64_t x3, int64_t x4, int64_t x5, int64_t x6, int64_t x7, int64_t x8, int64_t x9);
 int64_t* ptr(int64_t* x);
 int64_t* ptr_mut(int64_t* x);
 int64_t** ptr_ptr(int64_t** x);
@@ -165,6 +164,7 @@ cffi_vec2 ambiguous_2(cffi_vec2 x);
 bool ambiguous_3(cffi_vec1 x, cffi_vec2 y);
 cffi_vec namespaced_type(cffi_vec x);
 cffi_ffierror panics();
+void sleep(uint64_t millis);
 uint32_t pattern_ascii_pointer_1(uint8_t* x);
 uint32_t pattern_ascii_pointer_len(uint8_t* x, cffi_useasciistringpattern y);
 uint32_t pattern_ffi_slice_1(cffi_ffisliceu32 ffi_slice);
@@ -172,7 +172,7 @@ cffi_vec3f32 pattern_ffi_slice_2(cffi_ffislicevec3f32 ffi_slice, int32_t i);
 uint8_t pattern_ffi_slice_delegate(cffi_fptr_fn_FFISliceu8_rval_u8 callback);
 cffi_ffioptioninner pattern_ffi_option_1(cffi_ffioptioninner ffi_slice);
 cffi_inner pattern_ffi_option_2(cffi_ffioptioninner ffi_slice);
-cffi_ffierror api_entry_points(cffi_pointers* x);
+void my_api_init_v1(cffi_myapiv1* api);
 cffi_ffierror pattern_service_create(cffi_context** context_ptr, uint32_t value);
 cffi_ffierror pattern_service_destroy(cffi_context** context_ptr);
 uint32_t pattern_service_method(cffi_context* context);
@@ -297,6 +297,39 @@ class Inner(object):
         self._ptr_x = value
         self._ctx[0].x = value
 
+class MyAPIv1(object):
+    """"""
+    def __init__(self):
+        global _api, ffi
+        self._ctx = ffi.new("cffi_myapiv1[]", 1)
+
+    def array(n):
+        global _api, ffi
+        return ffi.new("cffi_myapiv1[]", n)
+
+    def ptr(self):
+        return self._ctx
+
+    @property
+    def ref_mut_option(self):
+        """"""
+        return self._ctx[0].ref_mut_option
+
+    @ref_mut_option.setter
+    def ref_mut_option(self, value):
+        self._ptr_ref_mut_option = value
+        self._ctx[0].ref_mut_option = value
+
+    @property
+    def tupled(self):
+        """"""
+        return self._ctx[0].tupled
+
+    @tupled.setter
+    def tupled(self, value):
+        self._ptr_tupled = value
+        self._ctx[0].tupled = value
+
 class Phantomu8(object):
     """"""
     def __init__(self):
@@ -320,49 +353,6 @@ class Phantomu8(object):
         self._ptr_x = value
         self._ctx[0].x = value
 
-class Pointers(object):
-    """"""
-    def __init__(self):
-        global _api, ffi
-        self._ctx = ffi.new("cffi_pointers[]", 1)
-
-    def array(n):
-        global _api, ffi
-        return ffi.new("cffi_pointers[]", n)
-
-    def ptr(self):
-        return self._ctx
-
-    @property
-    def f1(self):
-        """"""
-        return self._ctx[0].f1
-
-    @f1.setter
-    def f1(self, value):
-        self._ptr_f1 = value
-        self._ctx[0].f1 = value
-
-    @property
-    def f2(self):
-        """"""
-        return self._ctx[0].f2
-
-    @f2.setter
-    def f2(self, value):
-        self._ptr_f2 = value
-        self._ctx[0].f2 = value
-
-    @property
-    def f3(self):
-        """"""
-        return self._ctx[0].f3
-
-    @f3.setter
-    def f3(self, value):
-        self._ptr_f3 = value
-        self._ctx[0].f3 = value
-
 class SomeForeignType(object):
     """"""
     def __init__(self):
@@ -609,7 +599,6 @@ class FFIError:
 
 class callbacks:
     """Helpers to define `@ffi.callback`-style callbacks."""
-    fn_Vec3f32_pconst_Empty_rval_FFIError = "cffi_ffierror(cffi_vec3f32,cffi_empty*)"
     fn_Tupled_rval_Tupled = "cffi_tupled(cffi_tupled)"
     fn_pmut_i64_rval_bool = "bool(int64_t*)"
     fn_u8_rval_u8 = "uint8_t(uint8_t)"
@@ -693,6 +682,46 @@ class raw:
             x = x._ctx[0]
         return _api.primitive_i64(x)
 
+    def many_args_5(x0, x1, x2, x3, x4):
+        """"""
+        global _api
+        if hasattr(x0, "_ctx"):
+            x0 = x0._ctx[0]
+        if hasattr(x1, "_ctx"):
+            x1 = x1._ctx[0]
+        if hasattr(x2, "_ctx"):
+            x2 = x2._ctx[0]
+        if hasattr(x3, "_ctx"):
+            x3 = x3._ctx[0]
+        if hasattr(x4, "_ctx"):
+            x4 = x4._ctx[0]
+        return _api.many_args_5(x0, x1, x2, x3, x4)
+
+    def many_args_10(x0, x1, x2, x3, x4, x5, x6, x7, x8, x9):
+        """"""
+        global _api
+        if hasattr(x0, "_ctx"):
+            x0 = x0._ctx[0]
+        if hasattr(x1, "_ctx"):
+            x1 = x1._ctx[0]
+        if hasattr(x2, "_ctx"):
+            x2 = x2._ctx[0]
+        if hasattr(x3, "_ctx"):
+            x3 = x3._ctx[0]
+        if hasattr(x4, "_ctx"):
+            x4 = x4._ctx[0]
+        if hasattr(x5, "_ctx"):
+            x5 = x5._ctx[0]
+        if hasattr(x6, "_ctx"):
+            x6 = x6._ctx[0]
+        if hasattr(x7, "_ctx"):
+            x7 = x7._ctx[0]
+        if hasattr(x8, "_ctx"):
+            x8 = x8._ctx[0]
+        if hasattr(x9, "_ctx"):
+            x9 = x9._ctx[0]
+        return _api.many_args_10(x0, x1, x2, x3, x4, x5, x6, x7, x8, x9)
+
     def ptr(x):
         """"""
         global _api
@@ -836,6 +865,13 @@ Parameter x must point to valid data."""
         global _api
         return _api.panics()
 
+    def sleep(millis):
+        """"""
+        global _api
+        if hasattr(millis, "_ctx"):
+            millis = millis._ctx[0]
+        return _api.sleep(millis)
+
     def pattern_ascii_pointer_1(x):
         """"""
         global _api
@@ -889,12 +925,12 @@ Parameter x must point to valid data."""
             ffi_slice = ffi_slice._ctx[0]
         return _api.pattern_ffi_option_2(ffi_slice)
 
-    def api_entry_points(x):
+    def my_api_init_v1(api):
         """"""
         global _api
-        if hasattr(x, "_ctx"):
-            x = x._ctx[0]
-        return _api.api_entry_points(x)
+        if hasattr(api, "_ctx"):
+            api = api._ctx[0]
+        return _api.my_api_init_v1(api)
 
     def pattern_service_create(context_ptr, value):
         """"""
